// ignore_for_file: public_member_api_docs

import 'package:healthrian_common_support/healthrian_common_support.dart';
import 'package:mobx/mobx.dart';

part 'streams.g.dart';

class Streams = StreamsBase with _$Streams;

abstract class StreamsBase with Store {
  /// [rawStream] is a raw ecg stream from device.
  @observable
  Stream<List<int>>? rawStream;

  /// [decompressedStream] is a decompressed ecg stream.
  /// Where there is no compression, it is equal to [rawStream].
  ///
  /// The decompression codec is LZMA algorithm.
  @observable
  Stream<List<int>>? decompressedStream;

  /// [recentStream] is a recent stream,
  /// which is converted into double-typed values.
  @observable
  Stream<List<double>>? recentStream;

  /// [leadStateStream] is a stream to show lead states of ecg signal.
  /// Elements indicate state of RA, V6, LA, LL, V2,
  /// V3, V4, V5, and V1, in a row, respectively.
  @observable
  Stream<LeadState>? leadStateStream;

  /// [heartRateStream] is a stream to show heart rate.
  @observable
  Stream<int>? heartRateStream;

  /// [bufferedStreamEcg] is a buffered stream for ecg measurement.
  ///
  /// By default, it contains 30~40 seconds result.
  @observable
  Stream<Channels>? bufferedStreamEcg;

  /// [bufferedPlotStreamEcg] is a buffered stream for plotting ecg signals.
  ///
  /// By default, it contains 30~40 seconds result.
  @observable
  Stream<PlotChannels>? bufferedPlotStreamEcg;

  /// [bufferedPlotStreamEcg] is a buffered stream for plotting ecg signals.
  ///
  /// By default, it contains 30~40 seconds result.
  @observable
  Stream<PlotChannels>? bufferedPlotRTStreamEcg;

  /// performance test
  @observable
  Stream<PlotChannels>? bufferedPlotRTStreamQ1;

  @observable
  Stream<PlotChannels>? bufferedPlotRTStreamQ2;

  @observable
  Stream<PlotChannels>? bufferedPlotRTStreamQ3;

  @observable
  Stream<PlotChannels>? bufferedPlotRTStreamQ4;
}
